@@ -1,25 +1,25 @@
 package Parse::HTTP::UserAgent::Base::Dumper;
-$Parse::HTTP::UserAgent::Base::Dumper::VERSION = '0.40_02'; # TRIAL
-
-$Parse::HTTP::UserAgent::Base::Dumper::VERSION = '0.4002';use strict;
-use warnings;
-use Carp qw( croak );
+use strict;
+use vars qw( $VERSION );
 use Parse::HTTP::UserAgent::Constants qw(:all);
+use Carp qw( croak );
+
+$VERSION = '0.12';
 
 sub dumper {
-    my($self, @args) = @_;
-    my %opt = @args % 2 ? () : (
+    my $self = shift;
+    my %opt  = @_ % 2 ? () : (@_);
+    %opt = (
         type      => 'dumper',
         format    => 'none',
         interpret => 0,
-        @args
+        %opt
     );
-    my $meth = '_dumper_' . lc $opt{type};
+    my $meth = '_dumper_' . lc($opt{type});
     croak "Don't know how to dump with $opt{type}" if ! $self->can( $meth );
     my $buf = $self->$meth( \%opt );
     return $buf if defined wantarray;
-    my $pok = print $buf ."\n";
-    return;
+    print $buf ."\n";
 }
 
 sub _dump_to_struct {
@@ -44,10 +44,10 @@ sub _dumper_xml {
     my $opt  = shift;
     require XML::Simple;
     return  XML::Simple::XMLout(
-                $self->_dump_to_struct,
-                RootName => 'ua',
-                NoIndent => $opt->{format} ne 'pretty',
-            );
+        $self->_dump_to_struct,
+        RootName => 'ua',
+        NoIndent => $opt->{format} ne 'pretty',
+    );
 }
 
 sub _dumper_yaml {
@@ -58,40 +58,35 @@ sub _dumper_yaml {
 }
 
 sub _dumper_dumper {
-    # yeah, I know. Fugly code here
     my $self = shift;
     my $opt  = shift;
     my @ids  = $opt->{args} ?  @{ $opt->{args} } : $self->_object_ids;
     my $args = $opt->{args} ?                  1 : 0;
     my $max  = 0;
-    map { $max = length $_ if length $_ > $max; } @ids;
+    map { my $l = length $_; $max = $l if $l > $max; } @ids;
     my @titles = qw( FIELD VALUE );
     my $buf    = sprintf "%s%s%s\n%s%s%s\n",
                         $titles[0],
-                        (q{ } x (2 + $max - length $titles[0])),
+                        (' ' x (2 + $max - length $titles[0])),
                         $titles[1],
-                        q{-} x $max, q{ } x 2, q{-} x ($max*2);
+                        '-' x $max, ' ' x 2, '-' x ($max*2);
     require Data::Dumper;
-    my @buf;
     foreach my $id ( @ids ) {
         my $name = $args ? $id->{name} : $id;
         my $val  = $args ? $id->{value} : $self->[ $self->$id() ];
-        if ( $val && ref $val ) {
-            my $d = Data::Dumper->new([$val]);
-            $d->Indent(0);
-            my $rv = $d->Dump;
-            $rv =~ s{ \$VAR1 \s+ = \s+ }{}xms;
-            $rv =~ s{ ; }{}xms;
-            $val = $rv eq '[]' ? q{} : $rv;
-        }
-        push @buf, [
-            $name,
-            (q{ } x (2 + $max - length $name)),
-            defined $val ? $val : q{}
-        ];
-    }
-    foreach my $row ( sort { lc $a->[0] cmp lc $b->[0] } @buf ) {
-        $buf .= sprintf "%s%s%s\n", @{ $row };
+        $val = do {
+                    my $d = Data::Dumper->new([$val]);
+                    $d->Indent(0);
+                    my $rv = $d->Dump;
+                    $rv =~ s{ \$VAR1 \s+ = \s+ }{}xms;
+                    $rv =~ s{ ; }{}xms;
+                    $rv eq '[]' ? '' : $rv;
+                } if $val && ref $val;
+        $buf .= sprintf "%s%s%s\n",
+                        $name,
+                        (' ' x (2 + $max - length $name)),
+                        defined $val ? $val : ''
+                        ;
     }
     return $buf;
 }
@@ -102,24 +97,17 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-Parse::HTTP::UserAgent::Base::Dumper
-
-=head1 VERSION
-
-version 0.40_02
+Parse::HTTP::UserAgent::Dumper - Base class to dump parsed structure
 
 =head1 DESCRIPTION
 
+This document describes version C<0.12> of C<Parse::HTTP::UserAgent::Base::Dumper>
+released on C<27 August 2009>.
+
 The parsed structure can be dumped to a text table for debugging.
 
-=head1 NAME
-
-Parse::HTTP::UserAgent::Base::Dumper - Base class to dump parsed structure
-
 =head1 METHODS
 
 =head2 dumper
@@ -133,13 +121,16 @@ L<Parse::HTTP::UserAgent>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>
+Burak Gursoy <burak@cpan.org>.
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is copyright (c) 2009 by Burak Gursoy.
+Copyright 2009 Burak Gursoy. All rights reserved.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify 
+it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+at your option, any later version of Perl 5 you may have available.
 
 =cut
