@@ -2,7 +2,7 @@ package Parse::HTTP::UserAgent::Constants;
 use strict;
 use vars qw( $VERSION $OID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 BEGIN { $OID = -1 }
 use constant UA_STRING           => ++$OID; # just for information
@@ -13,7 +13,7 @@ use constant UA_VERSION_RAW      => ++$OID; # the parsed version
 use constant UA_VERSION          => ++$OID; # used for numerical ops. via qv()
 use constant UA_OS               => ++$OID; # Operating system
 use constant UA_LANG             => ++$OID; # the language of the ua interface
-use constant UA_TK               => ++$OID; # [Opera] ua toolkit
+use constant UA_TOOLKIT          => ++$OID; # [Opera] ua toolkit
 use constant UA_EXTRAS           => ++$OID; # Extra stuff (Toolbars?) non parsable junk
 use constant UA_DOTNET           => ++$OID; # [MSIE] List of .NET CLR versions
 use constant UA_STRENGTH         => ++$OID; # [MSIE] List of .NET CLR versions
@@ -29,13 +29,13 @@ use constant IS_PARSED           => ++$OID; # _parse() happened or not
 use constant IS_MAXTHON          => ++$OID; # Is this the dumb IE faker?
 use constant MAXID               =>   $OID;
 
-use constant RE_FIREFOX_NAMES => qr{Firefox|Iceweasel|Firebird|Phoenix}xms;
-use constant RE_DOTNET        => qr{ \A [.]NET \s+ CLR \s+ (.+?) \z }xms;
-use constant RE_WINDOWS_OS    => qr{ \A Win(dows|NT|[0-9]+)? }xmsi;
-use constant RE_SLASH         => qr{ / }xms;
-use constant RE_SPLIT_PARSE   => qr{ \s? [()] \s? }xms;
+use constant RE_FIREFOX_NAMES    => qr{Firefox|Iceweasel|Firebird|Phoenix }xms;
+use constant RE_DOTNET           => qr{ \A [.]NET \s+ CLR \s+ (.+?) \z    }xms;
+use constant RE_WINDOWS_OS       => qr{ \A Win(dows|NT|[0-9]+)?           }xmsi;
+use constant RE_SLASH            => qr{ /                                 }xms;
+use constant RE_SPLIT_PARSE      => qr{ \s? [()] \s?                      }xms;
 
-use constant LIST_ROBOTS      => qw(
+use constant LIST_ROBOTS         => qw(
     Wget
     curl
     libwww-perl
@@ -48,47 +48,47 @@ use constant LIST_ROBOTS      => qw(
 use Exporter ();
 
 BEGIN {
-@ISA         = qw( Exporter );
-%EXPORT_TAGS = (
-    object_ids => [qw(
-        IS_PARSED
-        IS_MAXTHON
-        UA_STRING
-        UA_UNKNOWN
-        UA_GENERIC
-        UA_NAME
-        UA_VERSION_RAW
-        UA_VERSION
-        UA_OS
-        UA_LANG
-        UA_TK
-        UA_EXTRAS
-        UA_DOTNET
-        UA_MOZILLA
-        UA_STRENGTH
-        UA_ROBOT
-        UA_WAP
-        UA_MOBILE
-        UA_PARSER
-        UA_DEVICE
-        UA_ORIGINAL_NAME
-        UA_ORIGINAL_VERSION
-        MAXID
-    )],
-    re => [qw(
-        RE_FIREFOX_NAMES
-        RE_DOTNET
-        RE_WINDOWS_OS
-        RE_SLASH
-        RE_SPLIT_PARSE
-    )],
-    list => [qw(
-        LIST_ROBOTS
-    )],
-);
+    @ISA         = qw( Exporter );
+    %EXPORT_TAGS = (
+        object_ids => [qw(
+            IS_PARSED
+            IS_MAXTHON
+            UA_STRING
+            UA_UNKNOWN
+            UA_GENERIC
+            UA_NAME
+            UA_VERSION_RAW
+            UA_VERSION
+            UA_OS
+            UA_LANG
+            UA_TOOLKIT
+            UA_EXTRAS
+            UA_DOTNET
+            UA_MOZILLA
+            UA_STRENGTH
+            UA_ROBOT
+            UA_WAP
+            UA_MOBILE
+            UA_PARSER
+            UA_DEVICE
+            UA_ORIGINAL_NAME
+            UA_ORIGINAL_VERSION
+            MAXID
+        )],
+        re => [qw(
+            RE_FIREFOX_NAMES
+            RE_DOTNET
+            RE_WINDOWS_OS
+            RE_SLASH
+            RE_SPLIT_PARSE
+        )],
+        list => [qw(
+            LIST_ROBOTS
+        )],
+    );
 
-@EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
-$EXPORT_TAGS{all} = [ @EXPORT_OK ];
+    @EXPORT_OK        = map { @{ $_ } } values %EXPORT_TAGS;
+    $EXPORT_TAGS{all} = [ @EXPORT_OK ];
 }
 
 1;
@@ -103,8 +103,8 @@ Parse::HTTP::UserAgent::Constants - Various constants
 
 =head1 DESCRIPTION
 
-This document describes version C<0.11> of C<Parse::HTTP::UserAgent::Constants>
-released on C<26 August 2009>.
+This document describes version C<0.12> of C<Parse::HTTP::UserAgent::Constants>
+released on C<27 August 2009>.
 
 Internal module
 
